"use strict";
var chalk = require('chalk');
var LOG_LEVELS = {
    error: {
        color: 'red'
    },
    warn: {
        color: 'yellow'
    },
    info: {
        color: 'cyan'
    },
    debug: {
        color: 'white'
    }
};
var log = function (message, severity) {
    if (severity === void 0) { severity = 'info'; }
    var color = LOG_LEVELS[severity].color || 'cyan';
    console.log(chalk[color](message));
};
var presets = {
    angular: {
        validate: function (message) {
            var MAX_LENGTH = 100;
            var PATTERN = /^(?:fixup!\s*)?(\w*)(\(([\w\$\.\*/-]*)\))?\: (.*)$/;
            var TYPES = {
                feat: true,
                fix: true,
                docs: true,
                style: true,
                refactor: true,
                perf: true,
                test: true,
                chore: true,
                revert: true
            };
            if (message.length >= MAX_LENGTH) {
                log("Message is longer than " + MAX_LENGTH + " characters!", 'error');
                return false;
            }
            var match = PATTERN.exec(message);
            if (!match) {
                log("Message does not match \"<type>(<scope>): <subject>\"! was: " + message, 'error');
                return false;
            }
            var type = match[1];
            if (!TYPES.hasOwnProperty(type)) {
                log("'" + type + "' is not an allowed type!", 'error');
                log("Valid types are: " + Object.keys(TYPES).join(', '), 'info');
                return false;
            }
            return true;
        },
        ignorePattern: /^WIP\:/
    },
    atom: {
        validate: function (message) {
            var MAX_LENGTH = 72;
            var EMOJIS = [
                ':art:',
                ':racehorse:',
                ':non-potable_water:',
                ':memo:',
                ':penguin:',
                ':apple:',
                ':checkered_flag:',
                ':bug:',
                ':fire:',
                ':green_heart:',
                ':white_check_mark:',
                ':lock:',
                ':arrow_up:',
                ':arrow_down:',
                ':shirt:'
            ];
            var PATTERN = new RegExp("^(" + EMOJIS.join('|') + ")(?: )(?:.*)$");
            if (message.length > MAX_LENGTH) {
                log("Message is longer than " + MAX_LENGTH + " characters!", 'error');
                return false;
            }
            var match = PATTERN.exec(message);
            if (!match) {
                log("Message does not match \"<emoji> <subject>\"! was: " + message, 'error');
                log("Valid emojis are: " + EMOJIS.join(', '), 'info');
                return false;
            }
            return true;
        }
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = presets;
